Package: bfbin2arm
Type: Package
Title: Bayes Factor Design for Two-Arm Binomial Trials
Version: 0.1.3
Date: 2026-05-06
Authors@R: 
    c(person(given = "Riko", family = "Kelter", role = c("aut", "cre"),
             email = "rkelter@uni-koeln.de"))
Description: Design and analysis of one- and two-stage binomial
    clinical phase II trials using Bayes factors. Implements Bayes factors
    for point-null and directional hypotheses, predictive densities under
    different hypotheses, and power and sample size calibration. Both one-arm
    trials with only a single treatment arm and two-arm trials with treatment
    and control arm are implemented for the one- and two-stage designs.
Depends: R (>= 4.0.0)
Imports: stats, VGAM, dplyr, parallel, utils, ggplot2, patchwork, rlang
Suggests: knitr, rmarkdown, kableExtra, testthat (>= 3.0.0)
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.3.3
VignetteBuilder: knitr
URL: https://arxiv.org/abs/2511.23144,
        https://arxiv.org/abs/2603.01715,
        https://arxiv.org/abs/2502.02914
NeedsCompilation: no
Packaged: 2026-06-01 17:53:51 UTC; riko
Author: Riko Kelter [aut, cre]
Maintainer: Riko Kelter <rkelter@uni-koeln.de>
Repository: CRAN
Date/Publication: 2026-06-01 19:40:02 UTC
Built: R 4.6.0; ; 2026-06-01 20:29:22 UTC; unix
