# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,singlearm_onestage_bf_design)
S3method(plot,singlearm_bf_design)
S3method(plot,singlearm_onestage_bf_design)
S3method(plot,twoarm_onestage_bf_design)
S3method(plot,twoarm_twostage_bf_design)
S3method(print,singlearm_onestage_bf_design)
S3method(print,summary.singlearm_bf_design)
S3method(print,summary.singlearm_onestage_bf_design)
S3method(print,summary.twoarm_onestage_bf_design)
S3method(print,summary.twoarm_twostage_bf_design)
S3method(print,twoarm_onestage_bf_design)
S3method(print,twoarm_twostage_bf_design)
S3method(summary,singlearm_bf_design)
S3method(summary,singlearm_onestage_bf_design)
S3method(summary,twoarm_onestage_bf_design)
S3method(summary,twoarm_twostage_bf_design)
export(BFminus0)
export(BFminus1)
export(BFplus0)
export(BFplus1)
export(BFplusMinus)
export(design_singlearm_bf)
export(design_singlearm_onestage_bf)
export(design_twoarm_onestage_bf)
export(design_twoarm_twostage_bf)
export(ntwoarmbinbf01)
export(optimal_twostage_2arm_bf)
export(optimal_twostage_singlearm_bf)
export(plot_twostage_2arm_bf)
export(postProbHminus)
export(postProbHplus)
export(powerbinbf01_fixed)
export(powerbinbf01seq)
export(powertwoarmbinbf01)
export(predictiveDensityH0)
export(predictiveDensityH1)
export(predictiveDensityHminus_trunc)
export(predictiveDensityHplus_trunc)
export(priorProbHminus)
export(priorProbHplus)
export(twoarmbinbf01)
export(twoarmbinbf_plus0_direct)
import(parallel)
importFrom(dplyr,`%>%`)
importFrom(ggplot2,aes)
importFrom(ggplot2,annotate)
importFrom(ggplot2,coord_cartesian)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_text)
importFrom(ggplot2,facet_grid)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,label_parsed)
importFrom(ggplot2,labeller)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_linetype_manual)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_minimal)
importFrom(ggplot2,unit)
importFrom(graphics,abline)
importFrom(graphics,arrows)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,layout)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot.new)
importFrom(graphics,points)
importFrom(graphics,rect)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(patchwork,plot_layout)
importFrom(rlang,.data)
importFrom(stats,dbeta)
importFrom(stats,dbinom)
importFrom(stats,density)
importFrom(stats,integrate)
importFrom(stats,pbeta)
importFrom(utils,flush.console)
importFrom(utils,globalVariables)
importFrom(utils,tail)
