% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/freq_oc_twoarm_helpers.R
\name{compute_freq_twostage_oc_2arm}
\alias{compute_freq_twostage_oc_2arm}
\title{Exact frequentist OCs for one two-stage two-arm BF design}
\usage{
compute_freq_twostage_oc_2arm(
  n1_1,
  n1_2,
  n2_1,
  n2_2,
  k,
  k_f,
  test,
  p1_power,
  p2_power,
  p_null_grid = NULL,
  a_0_a,
  b_0_a,
  a_1_a,
  b_1_a,
  a_2_a,
  b_2_a,
  a_1_a_Hminus,
  b_1_a_Hminus,
  a_2_a_Hminus,
  b_2_a_Hminus
)
}
\description{
Exact frequentist OCs for one two-stage two-arm BF design
}
\keyword{internal}
