% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/freq_oc_twoarm_helpers.R
\name{freq_t1e_twostage_twoarm_sup}
\alias{freq_t1e_twostage_twoarm_sup}
\title{Two-stage frequentist type-I error supremum over a null grid}
\usage{
freq_t1e_twostage_twoarm_sup(
  n1_1,
  n1_2,
  n2_1,
  n2_2,
  k,
  k_f,
  test,
  p_null_grid = NULL,
  a_0_a,
  b_0_a,
  a_1_a,
  b_1_a,
  a_2_a,
  b_2_a,
  a_1_a_Hminus,
  b_1_a_Hminus,
  a_2_a_Hminus,
  b_2_a_Hminus,
  alpha_target = NULL,
  tol_excess = 1e-04
)
}
\description{
Internal helper. For a given two-stage design (n1_1, n1_2, n2_1, n2_2),
computes the supremum of the two-stage frequentist type-I error over a grid
of null parameter configurations, using freq_oc_twostage_twoarm_fixed().
}
\keyword{internal}
